@@ -5,6 +5,7 @@ from pythautomata.automata.deterministic_finite_automaton import \
     DeterministicFiniteAutomaton as DFA
 from pythautomata.automata.non_deterministic_finite_automaton import \
     NondeterministicFiniteAutomaton as NFA
+from pythautomata.automata.symbolic_finite_automaton import SymbolicFiniteAutomaton
 from pythautomata.automata_definitions.bollig_habermehl_kern_leucker_automata import \
     BolligHabermehlKernLeuckerAutomata
 from pythautomata.automata_definitions.omlin_giles_automata import \
@@ -12,10 +13,12 @@ from pythautomata.automata_definitions.omlin_giles_automata import \
 from pythautomata.automata_definitions.other_automata import OtherAutomata
 from pythautomata.automata_definitions.tomitas_grammars import TomitasGrammars
 from pythautomata.automata_definitions.weighted_tomitas_grammars import WeightedTomitasGrammars
+from pythautomata.base_types.alphabet import Alphabet
+from pythautomata.base_types.symbolic_state import SymbolicState
 from pythautomata.model_comparators.dfa_comparison_strategy import \
     DFAComparisonStrategy as DFAComparator
 from pythautomata.model_comparators.hopcroft_karp_comparison_strategy import \
-    HopcroftKarpComparisonStrategy as NFAComparator
+    HopcroftKarpComparisonStrategy as HopcroftKarpComparison
 from pythautomata.utilities.automata_converter import AutomataConverter
 from pythautomata.model_comparators.wfa_comparison_strategy import WFAComparator
 
@@ -136,7 +139,7 @@ class TestAutomataComparison(TestCase):
         if type(automaton1) == DFA and type(automaton2) == DFA:
             comparator = DFAComparator()
         else:
-            comparator = NFAComparator()
+            comparator = HopcroftKarpComparison()
         areEquivalent = comparator.are_equivalent(automaton1, automaton2)
         return areEquivalent
 
@@ -166,19 +169,29 @@ class TestAutomataComparison(TestCase):
         weightedTomita4 = WeightedTomitasGrammars.get_automaton_4()
         comparator = WFAComparator()
         from pythautomata.base_types.symbol import SymbolStr
-        from pythautomata.base_types.alphabet import Alphabet   
+        from pythautomata.base_types.alphabet import Alphabet
         from pythautomata.automata.wheighted_automaton_definition.weighted_state import WeightedState
         from pythautomata.automata.wheighted_automaton_definition.probabilistic_deterministic_finite_automaton import \
-     ProbabilisticDeterministicFiniteAutomaton
-        q0 = WeightedState("q0", 1, 0.05)      
+            ProbabilisticDeterministicFiniteAutomaton
+        q0 = WeightedState("q0", 1, 0.05)
         binaryAlphabet = Alphabet(frozenset((SymbolStr('0'), SymbolStr('1'))))
         zero = binaryAlphabet['0']
-        one = binaryAlphabet['1']   
+        one = binaryAlphabet['1']
         q0.add_transition(zero, q0, 0.665)
-        q0.add_transition(one, q0, 0.285)       
+        q0.add_transition(one, q0, 0.285)
 
         states = {q0}
         comparator = WFAComparator()
-        single_state_wfa = ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas4")
-        counterexample = comparator.get_counterexample_between(weightedTomita4, single_state_wfa)
+        single_state_wfa = ProbabilisticDeterministicFiniteAutomaton(
+            binaryAlphabet, states, SymbolStr("$"), comparator, "WeightedTomitas4")
+        counterexample = comparator.get_counterexample_between(
+            weightedTomita4, single_state_wfa)
         assert(counterexample is not None)
+
+    def test_tomita1_vs_empty_sfa(self):
+        tomita1 = TomitasGrammars.get_automaton_1()
+        comparator = HopcroftKarpComparison()
+        init_state = SymbolicState('', is_final=True)
+        sfa = SymbolicFiniteAutomaton(
+            Alphabet(frozenset()), init_state, {init_state})
+        assert(not comparator.are_equivalent(tomita1, sfa))
